==> ocg_user-0.0.12.tar.gz: lib/src/repository/firebase.dart <==
import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_user/ocg_user.dart';
import 'package:cloud_firestore/cloud_firestore.dart';

class UserFirebaseRepository extends UserRepository {
  final FirebaseFirestore _firestore;

  UserFirebaseRepository(
    TokenRepository tokenRepository,
  )   : this._firestore = FirebaseFirestore.instance,
        super(tokenRepository);

  String get users => "users";
  CollectionReference get userCollection => _firestore.collection(users);

  @override
  Future<AppResponse<bool>> blockUser(String userId, bool block) {
    // TODO: implement blockUser
    throw UnimplementedError();
  }

  Future<AppResponse<String>> create(User user) async {
    try {
      if (InputHelper.isBlank(user.name)) {
        return AppResponse.named(error: "Name can not be empty");
      }
      var appResponse = await tokenRepository.getToken();
      if (!appResponse.isSuccess) {
        return AppResponse.named(error: "Not logged in");
      }

      user = user.copyWith(id: appResponse.data.userId);
      var json = user.toJson();
      await userCollection.doc(user.id).set(json);
      return AppResponse.named(data: user.id);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  Future<AppResponse<bool>> delete(String id) async {
    try {
      await userCollection.doc(id).delete();
      return AppResponse.named(data: true);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: "$e");
    }
  }

  Future<AppResponse<List<User>>> getList(
      {int page = 1, int count = 10}) async {
    try {
      var snapshot = await userCollection.get();
      if (snapshot.docs.length > 0) {
        var list = await Future.wait(snapshot.docs.map((e) async {
          return await _parseJson(e.data());
        }));
        list = list.where((element) => element != null).toList();
        return AppResponse.named(data: list);
      }
      return AppResponse.named(data: []);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  Future<AppResponse<User>> read(String id) async {
    try {
      var snapshot = await userCollection.doc(id).get();
      if (snapshot.exists) {
        return AppResponse.named(data: await _parseJson(snapshot.data()));
      } else {
        return AppResponse.named(error: "Not exists");
      }
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: "$e");
    }
  }

  Future<User> _parseJson(var json) async {
    return User.fromJson(json);
  }

  Future<AppResponse<bool>> update(User object) async {
    try {
      await _firestore.doc(object.id).update(object.toJson());
      return AppResponse.named(data: true);
    } catch (e) {
      return AppResponse.named(error: "Error $e");
    }
  }

  @override
  Future<AppResponse<User>> getSelf() async {
    try {
      AppResponse<String> idResponse = await getSelfId();
      if (idResponse.isSuccess) {
        return await read(idResponse.data);
      } else {
        return AppResponse.named(error: idResponse.error);
      }
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<List<User>>> getUsersList(List<String> userIds) async {
    try {
      var snapshot = await userCollection.where("id", whereIn: userIds).get();
      var users = await Future.wait(snapshot.docs.map((e) async {
        return await _parseJson(e.data());
      }));
      users = users.where((element) => element != null).toList();
      return AppResponse.named(data: users);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> updateSelf(User user) async {
    return await update(user);
  }
}

==> ocg_user-0.0.14.tar.gz: lib/src/repository/firebase.dart <==
import 'package:flutter/material.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_user/ocg_user.dart';
import 'package:cloud_firestore/cloud_firestore.dart';

class UserFirebaseRepository extends UserRepository {
  final FirebaseFirestore _firestore;
  final IDHelper idHelper;

  UserFirebaseRepository(
    TokenRepository tokenRepository,
    this.idHelper,
  )   : this._firestore = FirebaseFirestore.instance,
        super(tokenRepository);

  String get users => "users";
  CollectionReference get userCollection => _firestore.collection(users);

  @override
  Future<AppResponse<bool>> blockUser(String userId, bool block) {
    // TODO: implement blockUser
    throw UnimplementedError();
  }

  Future<AppResponse<String>> create(User user) async {
    try {
      if (user.id == null) {
        user = user.copyWith(id: idHelper.generateId());
      }
      var json = user.toJson();
      await userCollection.doc(user.id).set(json);
      return AppResponse.named(data: user.id);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  Future<AppResponse<bool>> delete(String id) async {
    try {
      await userCollection.doc(id).delete();
      return AppResponse.named(data: true);
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: "$e");
    }
  }

  Future<AppResponse<List<User>>> getList(
      {int page = 1, int count = 10}) async {
    try {
      var snapshot = await userCollection.get();
      if (snapshot.docs.length > 0) {
        var list = await Future.wait(snapshot.docs.map((e) async {
          return await _parseJson(e.data());
        }));
        list = list.where((element) => element != null).toList();
        return AppResponse.named(data: list);
      }
      return AppResponse.named(data: []);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  Future<AppResponse<User>> read(String id) async {
    try {
      var snapshot = await userCollection.doc(id).get();
      if (snapshot.exists) {
        return AppResponse.named(data: await _parseJson(snapshot.data()));
      } else {
        return AppResponse.named(error: "Not exists");
      }
    } catch (e) {
      debugPrint("Error $e");
      return AppResponse.named(error: "$e");
    }
  }

  Future<User> _parseJson(var json) async {
    return User.fromJson(json);
  }

  Future<AppResponse<bool>> update(User object) async {
    try {
      await _firestore.doc(object.id).update(object.toJson());
      return AppResponse.named(data: true);
    } catch (e) {
      return AppResponse.named(error: "Error $e");
    }
  }

  @override
  Future<AppResponse<User>> getSelf() async {
    try {
      AppResponse<String> idResponse = await getSelfId();
      if (idResponse.isSuccess) {
        return await read(idResponse.data);
      } else {
        return AppResponse.named(error: idResponse.error);
      }
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<List<User>>> getUsersList(List<String> userIds) async {
    try {
      var snapshot = await userCollection.where("id", whereIn: userIds).get();
      var users = await Future.wait(snapshot.docs.map((e) async {
        return await _parseJson(e.data());
      }));
      users = users.where((element) => element != null).toList();
      return AppResponse.named(data: users);
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  @override
  Future<AppResponse<bool>> updateSelf(User user) async {
    return await update(user);
  }
}
